@@ -1,7 +1,9 @@
 package main
 
 import (
+	"math/rand"
 	"os"
+	"time"
 
 	"github.com/smira/aptly/aptly"
 	"github.com/smira/aptly/cmd"
@@ -17,5 +19,7 @@ func main() {
 
 	aptly.Version = Version
 
+	rand.Seed(time.Now().UnixNano())
+
 	os.Exit(cmd.Run(cmd.RootCommand(), os.Args[1:], true))
 }
